
rm(list = ls())

# ---- Libraries ----

library(dplyr)
library(tidyr)
library(stringr)
library(broom) # to make tidy tables from model summaries 
library(ggplot2)
library(patchwork)
library(ggpubr)
library(flextable)
library(ggeffects)
library(MASS)


# ---- Functions ----


# ggplot theme 
theme_set(theme_classic2())

# Table layout 
i = 16.5      # width of the side borders in the word_document output (in centimeters)
w = i*0.3937  # width of the side borders in the word_document output (in inches)

style_table <- function(table) {
  table <- table %>% 
    flextable() %>%
    align(align = "left", part = "all") %>% 
    colformat_double(digits = 3) %>%
    fontsize(size = 11, part = "all") %>% 
    # font(fontname = "Times New Roman", part = "all") %>%
    bold(bold = T, part = "header") %>% 
    width(., width = (w/(ncol(table))))
  return(table)
}

round2 <- function(value) {
  format(round(value, 2), nsmall = 2)
}

round3 <- function(value) {
  format(round(value, 3), nsmall = 3)
}

Sys.setlocale("LC_ALL","en_US.UTF-8") # to make the +- sign and special characters work 


estimate_SE <-function(estimate, SE){
  paste0(round2(estimate), sep = " ", "±", sep = " ", round2(SE))
}


# Packages to cite:

knitr::write_bib(c(.packages(), "bookdown"), "packages.bib")
R.Version()
