
#source("00-load-everything.R")

# ---- Variation in sea age among years ------------------------------------------------------------------------------------------- 

# Females
modF <- lm(seaAge_firstspawn ~ - 1 
           + offset(seaAge_correction) 
           + factor(year_smolt),
           data = df)

summary(modF)

# Males
modM <- lm(seaAge_firstspawn ~ - 1 
           + offset(seaAge_correction) 
           + factor(year_smolt),
           data = dm)

summary(modM)


# ---- Variation in sea age among years when including additive and dominance effects of vgll3 and six6 -----------------------

# Females
modF_vgll3_six6 <- lm(seaAge_firstspawn ~ - 1 
                      + offset(seaAge_correction) 
                      + factor(year_smolt) 
                      + a_vgll3 
                      + d_vgll3 
                      + a_six6 
                      + d_six6,
                      data = df)

summary(modF_vgll3_six6)

# Males
modM_vgll3_six6 <- lm(seaAge_firstspawn ~ - 1 
                      + offset(seaAge_correction) 
                      + factor(year_smolt) 
                      + a_vgll3 
                      + d_vgll3 
                      + a_six6 
                      + d_six6, 
                      data = dm)

summary(modM_vgll3_six6)


# ---- Differences between years in additive and dominance effect  ----------------------------------------------------------------------

# Females
modF_vgll3_six6_year <- lm(seaAge_firstspawn ~  - 1 
                           + offset(seaAge_correction) 
                           + factor(year_smolt) 
                           + a_six6 
                           + d_six6  
                           + factor(year_smolt):a_six6 
                           + factor(year_smolt):d_six6 
                           + a_vgll3 
                           + d_vgll3 
                           + factor(year_smolt):a_vgll3 
                           + factor(year_smolt):d_vgll3, 
                           data = df)

summary(modF_vgll3_six6_year)



# Males
modM_vgll3_six6_year <- lm(seaAge_firstspawn ~  - 1 
                           + offset(seaAge_correction) 
                           + factor(year_smolt) 
                           + a_six6 
                           + d_six6  
                           + factor(year_smolt):a_six6 
                           + factor(year_smolt):d_six6 
                           + a_vgll3 
                           + d_vgll3 
                           + factor(year_smolt):a_vgll3 
                           + factor(year_smolt):d_vgll3, 
                           data = dm)
summary(modM_vgll3_six6_year)


# ---- Contrast to each year in additive and dominance effects ---------------------------------------------------------------

#  Models with each year as set as the reference year so that we can make comparison between all pairs of years  

# Females 
df$year_smolt_fac <- as.factor(df$year_smolt)
df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2013")
modF_vgll3_six6_year13 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year13)

df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2014")
modF_vgll3_six6_year14 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year14)

df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2015")
modF_vgll3_six6_year15 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year15)

# Lack one six6 genotype for females in 2015, therefore don't include six6 dominance effect in this year 
df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2015")
modF_vgll3_six6_year15 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year15)

df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2016")
modF_vgll3_six6_year16 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year16)

df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2017")
modF_vgll3_six6_year17 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year17)


df$year_smolt_fac <- relevel(df$year_smolt_fac, ref = "2018")
modF_vgll3_six6_year18 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = df)
summary(modF_vgll3_six6_year18)


# MALES
dm$year_smolt_fac <- as.factor(dm$year_smolt)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2013")
modM_vgll3_six6_year13 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year13)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2014")
modM_vgll3_six6_year14 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year14)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2015")
modM_vgll3_six6_year15 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year15)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2016")
modM_vgll3_six6_year16 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year16)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2017")
modM_vgll3_six6_year17 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year17)

dm$year_smolt_fac <- relevel(dm$year_smolt_fac, ref = "2018")
modM_vgll3_six6_year18 <- lm(seaAge_firstspawn ~ a_vgll3*year_smolt_fac + d_vgll3*year_smolt_fac   + a_six6*year_smolt_fac  + d_six6*year_smolt_fac  + offset(seaAge_correction), data = dm)
summary(modM_vgll3_six6_year18)
