
#source("05-genotype-year-interaction.R")
source("00-run-prep-scripts.R")


# ---- Table with additive and dominance effect per year, for each locus and sex ------------------------------------------------

d_add_dom <- 
  rbind(
    rbind(
      tidy(modF_vgll3_six6_year13), 
      tidy(modF_vgll3_six6_year14),
      tidy(modF_vgll3_six6_year15) %>% filter(!(term == "a_six6")),  # additive effect does not mean the same thing when it's from EL to LL
      tidy(modF_vgll3_six6_year16),
      tidy(modF_vgll3_six6_year17),
      tidy(modF_vgll3_six6_year18)
    )%>% 
      filter(term == "a_six6" | term == "d_six6" | term == "a_vgll3" | term == "d_vgll3") %>% dplyr::select(term, estimate, std.error)%>% 
      mutate(year_smolt = c(rep(c(2013:2014), each = 4),rep(2015, times = 2),rep(c(2016:2018), each = 4)
      ), Sex = "Female"),
    
    
    rbind(
      tidy(modM_vgll3_six6_year13), 
      tidy(modM_vgll3_six6_year14),
      tidy(modM_vgll3_six6_year15),
      tidy(modM_vgll3_six6_year16),
      tidy(modM_vgll3_six6_year17),
      tidy(modM_vgll3_six6_year18)
    )%>% 
      filter(term == "a_six6" | term == "d_six6"| term == "a_vgll3" | term == "d_vgll3") %>% dplyr::select(term, estimate, std.error) %>% 
      mutate(year_smolt = rep(c(2013:2018), each = 4), Sex = "Male")
  ) %>% 
  mutate(Gene = if_else(term == "a_vgll3" | term == "d_vgll3", "vgll3", "six6"),
         Term = if_else(term == "a_six6" |  term == "a_vgll3", "additive", "dominance"),
  ) 

# error-corrected among-year variances and standard deviations in additive and dominance effects ------

d_add_dom <- 
  d_add_dom %>% group_by(Sex, Gene, Term) %>% mutate(variance = var(estimate),
                                                     mean_SE2 = mean(std.error^2),
                                                     variance_SE_corr = if_else(variance > mean_SE2, variance - mean_SE2, 0),
                                                     SD_SE_corr = if_else(variance_SE_corr > 0, sqrt(variance_SE_corr), 0),
                                                     var_uncertain = if_else(variance_SE_corr > 0, (1-variance_SE_corr/variance)*100, 100)) 




# FIG 3B ADDITIVE AND DOMINANCE SIX6 -----

# error-corrected SD in additive and dominance effect 
sd_six6_ad <- d_add_dom %>% filter(Gene == "six6") %>% group_by(Term, Sex) %>% slice(1) %>% mutate(SD = round2(SD_SE_corr))%>% dplyr::select(SD, Term, Sex)

sd_six6_ad$label[sd_six6_ad$Term == "additive" & sd_six6_ad$Sex == "Female"] <- as.character(expression(sigma[a] == "0.10"))
sd_six6_ad$label[sd_six6_ad$Term == "dominance" & sd_six6_ad$Sex == "Female"] <- as.character(expression(sigma[d] == 0.07))

sd_six6_ad$label[sd_six6_ad$Term == "additive" & sd_six6_ad$Sex == "Male"] <- as.character(expression(sigma[a] == "0.00"))
sd_six6_ad$label[sd_six6_ad$Term == "dominance" & sd_six6_ad$Sex == "Male"] <- as.character(expression(sigma[d] == "0.00"))


sd_six6_ad$year_smolt <- c(2014.5, 2014.5, 2016.5, 2016.5)
sd_six6_ad$estimate <- 0.6

d_add_dom %>% filter(Gene == "six6") %>% 
  ggplot(aes(x = year_smolt, y = estimate, col = Term))+
  geom_point(position = position_dodge(width = 0.3))+
  geom_text(data = sd_six6_ad, aes(label = label), parse = T, show.legend = FALSE)+
  geom_hline(aes(yintercept = 0), linetype = "dashed")+
  geom_errorbar(aes(ymin = estimate - std.error, ymax = estimate + std.error), position = position_dodge(width = 0.3), width = 0.5) +
  facet_grid(. ~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("black", "darkgrey"))+
  ylab(expression(paste("Genetic effect of " ,italic("six6"), "(yr)")))



# FIG 2B ADDITIVE AND DOMINANCE VGLL3 -----

# error-corrected SD in additive and dominance effect 

sd_vgll3_ad <- d_add_dom %>% filter(Gene == "vgll3") %>% group_by(Term, Sex) %>% slice(1) %>% mutate(SD = round2(SD_SE_corr))%>% dplyr::select(SD, Term, Sex)

sd_vgll3_ad$label[sd_vgll3_ad$Term == "additive" & sd_vgll3_ad$Sex == "Female"] <- as.character(expression(sigma[a] == "0.00"))
sd_vgll3_ad$label[sd_vgll3_ad$Term == "dominance" & sd_vgll3_ad$Sex == "Female"] <- as.character(expression(sigma[d] == "0.13"))

sd_vgll3_ad$label[sd_vgll3_ad$Term == "additive" & sd_vgll3_ad$Sex == "Male"] <- as.character(expression(sigma[a] == "0.09"))
sd_vgll3_ad$label[sd_vgll3_ad$Term == "dominance" & sd_vgll3_ad$Sex == "Male"] <- as.character(expression(sigma[d] == "0.19"))


sd_vgll3_ad$year_smolt <- c(2014.5, 2014.5, 2016.5, 2016.5)
sd_vgll3_ad$estimate <- 0.8

d_add_dom %>% filter(Gene == "vgll3") %>% 
  ggplot(aes(x = year_smolt, y = estimate, col = Term))+
  geom_point(position = position_dodge(width = 0.3))+
  geom_text(data = sd_vgll3_ad, aes(label = label), parse = T, show.legend = FALSE)+
  geom_hline(aes(yintercept = 0), linetype = "dashed")+
  geom_errorbar(aes(ymin = estimate - std.error, ymax = estimate + std.error), position = position_dodge(width = 0.3), width = 0.5) +
  facet_grid(. ~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("black", "darkgrey"))+
  ylab(expression(paste("Genetic effect of " ,italic("vgll3"), "(yr)")))


# save the data used to make the plots: 
saveRDS(d_add_dom, "figs/data_additive_and_dominance_effect_year.rds")
saveRDS(sd_vgll3_ad, "figs/data_sd_vgll3_ad.rds")
saveRDS(sd_six6_ad, "figs/data_sd_six6_ad.rds")


