
source("00-run-prep-scripts.R")

# ---- Tables with pairwise differences in additive and dominance effect of vgll3  ----------------------------------------------------

# vgll3 difference in additive and dominance effect in each year 
# males
adM <-
  rbind(
    tidy(modM_vgll3_six6_year13)[11:20,] %>% mutate(Year = "2013", Term = c(rep(c("a", "d"), each = 5))),
    tidy(modM_vgll3_six6_year14)[c(12:15,17:20),]%>% mutate(Year = "2014", Term = c(rep(c("a", "d"), each = 4))),
    tidy(modM_vgll3_six6_year15)[c(13:15,18:20),]%>% mutate(Year = "2015", Term = c(rep(c("a", "d"), each = 3))),
    tidy(modM_vgll3_six6_year16)[c(14:15,19:20),]%>% mutate(Year = "2016", Term = c(rep(c("a", "d"), each = 2))),
    tidy(modM_vgll3_six6_year17)[c(15,20),]%>% mutate(Year = "2017", Term = c("a", "d"))
  )
adM$"Contrast to" <- c(rep(2014:2018, times = 2), rep(2015:2018, times = 2), rep(2016:2018, times = 2), rep(2017:2018, times = 2), c(2018, 2018))

adM$contrast_SE <- estimate_SE(adM$estimate, adM$std.error)

adM <- adM %>% dplyr::select(Year, "Contrast to", Term, contrast_SE) %>% pivot_wider(values_from = contrast_SE, names_from = Term) %>% 
  mutate(contrast_ad = paste0(a, sep = " ", "(", d, ")"))

# females 
adF <-
  rbind(
    tidy(modF_vgll3_six6_year13)[11:20,] %>% mutate(Year = "2013", Term = c(rep(c("a", "d"), each = 5))),
    tidy(modF_vgll3_six6_year14)[c(12:15,17:20),]%>% mutate(Year = "2014", Term = c(rep(c("a", "d"), each = 4))),
    tidy(modF_vgll3_six6_year15)[c(12:14,17:19),]%>% mutate(Year = "2015", Term = c(rep(c("a", "d"), each = 3))),
    tidy(modF_vgll3_six6_year16)[c(14:15,19:20),]%>% mutate(Year = "2016", Term = c(rep(c("a", "d"), each = 2))),
    tidy(modF_vgll3_six6_year17)[c(15,20),]%>% mutate(Year = "2017", Term = c("a", "d"))
  )
adF$"Contrast to" <- c(rep(2014:2018, times = 2), rep(2015:2018, times = 2), rep(2016:2018, times = 2), rep(2017:2018, times = 2), c(2018, 2018))

adF$contrast_SE <- estimate_SE(adF$estimate, adF$std.error)

adF <- adF %>% dplyr::select(Year, "Contrast to", Term, contrast_SE) %>% pivot_wider(values_from = contrast_SE, names_from = Term) %>% 
  mutate(contrast_ad = paste0(a, sep = " ", "(", d, ")"))


# females vgll3 additive
contrasts_vgll3_a_females <- style_table(adF %>% dplyr::select(a, Year, "Contrast to")  %>%  pivot_wider(values_from = a, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) 

# females vgll3 dominance
contrasts_vgll3_d_females <-style_table(adF %>% dplyr::select(d, Year, "Contrast to")  %>%  pivot_wider(values_from = d, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) %>% 
  bold(i = 3, j = 4) %>%  # 15-16 dominance
  bold(i = 3,j = 6)       # 15-18 dominance

# males vgll3 additive 
contrasts_vgll3_a_males <- style_table(adM %>% dplyr::select(a, Year, "Contrast to")  %>%  pivot_wider(values_from = a, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) %>% 
  bold(i = 1, j = 4) %>%  # 13-16 additive
  bold(i = 3, j = 4)      # 15-16 additive

# males vgll3 dominance
contrasts_vgll3_d_males <-style_table(adM %>% dplyr::select(d, Year, "Contrast to")  %>%  pivot_wider(values_from = d, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) %>% 
  bold(i = 2, j = 3) %>%  # 14-15 dominance
  bold(i = 3, j = 4) %>%  # 15-16 dominance
  bold(i = 4,j = 6)       # 16-18 dominance



# ---- Tables with pairwise differences in additive and dominance effect of six6  ----------------------------------------------------

# males 
adM_six6 <-
  rbind(
    tidy(modM_vgll3_six6_year13)[21:30,] %>% mutate(Year = "2013", Term = c(rep(c("a", "d"), each = 5))),
    tidy(modM_vgll3_six6_year14)[c(22:25,27:30),]%>% mutate(Year = "2014", Term = c(rep(c("a", "d"), each = 4))),
    tidy(modM_vgll3_six6_year15)[c(23:25,28:30),]%>% mutate(Year = "2015", Term = c(rep(c("a", "d"), each = 3))),
    tidy(modM_vgll3_six6_year16)[c(24:25,29:30),]%>% mutate(Year = "2016", Term = c(rep(c("a", "d"), each = 2))),
    tidy(modM_vgll3_six6_year17)[c(25,30),]%>% mutate(Year = "2017", Term = c("a", "d"))
  )
adM_six6$"Contrast to" <- c(rep(2014:2018, times = 2), rep(2015:2018, times = 2), rep(2016:2018, times = 2), rep(2017:2018, times = 2), c(2018, 2018))
adM_six6$contrast_SE <- estimate_SE(adM_six6$estimate, adM_six6$std.error)
adM_six6 <- adM_six6 %>% dplyr::select(Year, "Contrast to", Term, contrast_SE) %>% pivot_wider(values_from = contrast_SE, names_from = Term) %>% 
  mutate(contrast_ad = paste0(a, sep = " ", "(", d, ")"))


# females 
adF_six6 <-
  rbind(
    tidy(modF_vgll3_six6_year13)[21:30,] %>% mutate(Year = "2013", Term = c(rep(c("a", "d"), each = 5))),
    tidy(modF_vgll3_six6_year14)[c(22:25,27:30),]%>% mutate(Year = "2014", Term = c(rep(c("a", "d"), each = 4))),
    tidy(modF_vgll3_six6_year15)[c(23:25,28:30),]%>% mutate(Year = "2015", Term = c(rep(c("a", "d"), each = 3))),
    tidy(modF_vgll3_six6_year16)[c(24:25,29:30),]%>% mutate(Year = "2016", Term = c(rep(c("a", "d"), each = 2))),
    tidy(modF_vgll3_six6_year17)[c(25,30),]%>% mutate(Year = "2017", Term = c("a", "d"))
  )
adF_six6$"Contrast to" <- c(rep(2014:2018, times = 2), rep(2015:2018, times = 2), rep(2016:2018, times = 2), rep(2017:2018, times = 2), c(2018, 2018))
adF_six6$estimate[adF_six6$Year == "2015"] <- NA
adF_six6$estimate[adF_six6$"Contrast to" == "2015"] <- NA
adF_six6$contrast_SE <- with(adF_six6, ifelse(!is.na(estimate), estimate_SE(adF_six6$estimate, adF_six6$std.error), NA))
adF_six6 <- adF_six6 %>% dplyr::select(Year, "Contrast to", Term, contrast_SE) %>% pivot_wider(values_from = contrast_SE, names_from = Term) %>% 
  mutate(contrast_ad = paste0(a, sep = " ", "(", d, ")"))



# tables with contrasts six6 
# females six6 additive
contrasts_six6_a_females <- style_table(adF_six6 %>% dplyr::select(a, Year, "Contrast to")  %>%  pivot_wider(values_from = a, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) %>% 
  bold(i = 2, j = 5) %>%  # 14-17 additive 
  bold(i = 4, j = 5) %>%  # 16-17 additive 
  bold(i = 5, j = 6)      # 17-18 additive 


# females six6 dominance
contrasts_six6_d_females <-style_table(adF_six6 %>% dplyr::select(d, Year, "Contrast to")  %>%  pivot_wider(values_from = d, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2))

# males six6 additive 
contrasts_six6_a_males <- style_table(adM_six6 %>% dplyr::select(a, Year, "Contrast to")  %>%  pivot_wider(values_from = a, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) 

# males six6 dominance
contrasts_six6_d_males <-style_table(adM_six6 %>% dplyr::select(d, Year, "Contrast to")  %>%  pivot_wider(values_from = d, names_from = "Contrast to")) %>% 
  align(j = 2:6, align = "right", part = "all") %>% 
  add_header_row(values = c(NA, "Contrast to", NA), colwidths = c(1, 3, 2)) 


# ---- Tables with pairwise differences between years in additive and dominance effects of vgll3 and six6 in females and males ----------------------

# print(contrasts_vgll3_a_females %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the additive effect of vgll3 in females."), preview = "docx")
# print(contrasts_vgll3_d_females %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the dominance effect of vgll3 in females."), preview = "docx")
# print(contrasts_vgll3_a_males %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the additive effect of vgll3 in males."), preview = "docx")
# print(contrasts_vgll3_d_males %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the dominance effect of vgll3 in males."), preview = "docx")
# print(contrasts_six6_a_females %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the additive effect of six6 in females."), preview = "docx")
# print(contrasts_six6_d_females %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the dominance effect of six6 in females."), preview = "docx")
# print(contrasts_six6_a_males %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the additive effect of six6 in males."), preview = "docx")
# print(contrasts_six6_d_males %>% set_caption(caption = "Pairwise contrasts between years (?? standard error) in the dominance effect of six6 in males."), preview = "docx")
