

rm(list = ls())

# fig 2A 

data_vgll3_genotype_year <- readRDS("figs/data_vgll3_genotype_year.rds")
data_vgll3_individual_seaage <- readRDS("figs/data_vgll3_individual_seaage.rds")
data_vgll3_sd <- readRDS("figs/data_vgll3_sd.rds")
data_vgll3_sd$predicted <- c(1.5, 1.2, 0.9,  2.7, 3, 3.3)           # adjust position of text labels
data_vgll3_sd$year_smolt <- c(2014, 2014, 2014, 2017, 2017, 2017)

fig_genotypes_vgll3 <- 
data_vgll3_genotype_year %>% ggplot(aes(x = year_smolt, y = predicted, col = Genotype))+
  geom_line(position = position_dodge(width = 0.3))+
  facet_wrap(.~ Sex)+
  geom_point(aes(shape = Genotype), position = position_dodge(width = 0.3))+
  geom_text(data = data_vgll3_sd , aes(label = label), parse = T, show.legend = FALSE)+
  geom_errorbar(aes(ymin = predicted - se, ymax = predicted + se), position = position_dodge(width = 0.3), width = 0.5)+
  geom_jitter(data = data_vgll3_individual_seaage , aes(x = year_smolt, y = seaAge_firstspawn_123plus, col = Genotype), alpha = 0.1, width = 0.3, height = 0.2, size = 0.5)+
  scale_y_continuous("Sea age (yr)", breaks = seq(1,3, 1))+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("#CC79A7", "#009E73","#D55E00"))


# fig 3A

data_six6_genotype_year <- readRDS("figs/data_six6_genotype_year.rds")
data_six6_individual_seaage <- readRDS("figs/data_six6_individual_seaage.rds")
data_six6_sd <- readRDS("figs/data_six6_sd.rds")
data_six6_sd$predicted <- c(1.5, 1.2, 0.9,  2.5, 2.8, 3.1)
data_six6_sd$year_smolt <- c(2014, 2014, 2014, 2017, 2017, 2017)


fig_genotypes_six6 <- data_six6_genotype_year %>% ggplot(aes(x = year_smolt, y = predicted, col = Genotype))+
  geom_line(position = position_dodge(width = 0.3))+
  facet_wrap(.~ Sex)+
  geom_point(aes(shape = Genotype), position = position_dodge(width = 0.3))+
  geom_text(data = data_six6_sd , aes(label = label), parse = T, show.legend = FALSE)+
  geom_errorbar(aes(ymin = predicted - se, ymax = predicted + se), position = position_dodge(width = 0.3), width = 0.5)+
  geom_jitter(data = data_six6_individual_seaage , aes(x = year_smolt, y = seaAge_firstspawn_123plus, col = Genotype), alpha = 0.1, width = 0.3, height = 0.2, size = 0.5)+
  scale_y_continuous("Sea age (yr)", breaks = seq(1,3, 1))+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("#CC79A7", "#009E73","#D55E00"))


# fig 2B

data_additive_and_dominance_effect_year <- readRDS("figs/data_additive_and_dominance_effect_year.rds")
data_additive_and_dominance_effect_year$Term <- with(data_additive_and_dominance_effect_year, ifelse(Term == "additive", "additive (a)", "dominance (d)"))


data_sd_vgll3_ad <- readRDS("figs/data_sd_vgll3_ad.rds")
data_sd_vgll3_ad$Term <- with(data_sd_vgll3_ad, ifelse(Term == "additive", "additive (a)", "dominance (d)"))
data_sd_vgll3_ad$year_smolt <- c(2014, 2014, 2016, 2016) 
data_sd_vgll3_ad$estimate <- c(0.7) 

fig_additive_and_dominance_effect_year_vgll3 <- data_additive_and_dominance_effect_year %>% filter(Gene == "vgll3") %>% 
  ggplot(aes(x = year_smolt, y = estimate, col = Term))+
  geom_point(position = position_dodge(width = 0.3))+
  geom_text(data = data_sd_vgll3_ad, aes(label = label), parse = T, show.legend = FALSE)+
  geom_hline(aes(yintercept = 0), linetype = "dashed")+
  geom_errorbar(aes(ymin = estimate - std.error, ymax = estimate + std.error), position = position_dodge(width = 0.3), width = 0.5) +
  facet_grid(. ~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("black", "darkgrey"))+
  ylab("Genetic effect (yr)")

# fig 3B
data_sd_six6_ad <- readRDS("figs/data_sd_six6_ad.rds")
data_sd_six6_ad$Term <- with(data_sd_six6_ad, ifelse(Term == "additive", "additive (a)", "dominance (d)"))
data_sd_six6_ad$year_smolt <- c(2014, 2014, 2016, 2016) 
data_sd_six6_ad$estimate <- c(0.50) 

fig_additive_and_dominance_effect_year_six6 <- data_additive_and_dominance_effect_year %>% filter(Gene == "six6") %>% 
  ggplot(aes(x = year_smolt, y = estimate, col = Term))+
  geom_point(position = position_dodge(width = 0.3))+
  geom_text(data = data_sd_six6_ad, aes(label = label), parse = T, show.legend = FALSE)+
  geom_hline(aes(yintercept = 0), linetype = "dashed")+
  geom_errorbar(aes(ymin = estimate - std.error, ymax = estimate + std.error), position = position_dodge(width = 0.3), width = 0.5) +
  facet_grid(. ~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  scale_color_manual(values = c("black", "darkgrey"))+
  ylab("Genetic effect (yr)")


# Fig 2C
d_evolvability_vgll3 <- readRDS("figs/d_evolvability_vgll3.rds")
sd_vgll3_evolv <- readRDS("figs/sd_vgll3_evolv.rds")
sd_vgll3_evolv$evolvability <- c(0.023)
sd_vgll3_evolv$year_smolt <- c(2015)

fig_evolvability_vgll3 <- d_evolvability_vgll3 %>% 
  ggplot(aes(x = year_smolt, y = (evolvability*100)))+
  geom_col()+
  geom_text(data = sd_vgll3_evolv, aes(label = label), parse = T)+
  facet_grid(.~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  ylab("Evolvability (%)")

# Fig 3C
d_evolvability_six6 <- readRDS("figs/d_evolvability_six6.rds")
sd_six6_evolv <- readRDS("figs/sd_six6_evolv.rds")
sd_six6_evolv$year_smolt <- c(2015)

fig_evolvability_six6 <- d_evolvability_six6 %>% 
  ggplot(aes(x = year_smolt, y = (evolvability*100)))+
  geom_col()+
  geom_text(data = sd_six6_evolv, aes(label = label), parse = T)+
  facet_grid(.~ Sex)+
  scale_x_continuous("Year of outmigration", breaks = seq(2013, 2018, 1))+
  ylab("Evolvability (%)")

# ----- Combine plots ------

# fig 2


fig2 <- (fig_genotypes_vgll3 + guides(col=guide_legend(title=expression(paste(italic("vgll3"), " genotype"))),
                              shape=guide_legend(title=expression(paste(italic("vgll3"), " genotype")))) +
           theme(axis.title.x = element_blank()))/
  (fig_additive_and_dominance_effect_year_vgll3 + theme(axis.title.x = element_blank()))/
  fig_evolvability_vgll3 +
  plot_annotation(tag_levels = 'A')

fig2

ggsave(fig2, filename = "figs/Figure_2.pdf", width = 18, height = 18, units = "cm", device = cairo_pdf(), scale = 1)

# fig3 


fig3 <- (fig_genotypes_six6 + guides(col=guide_legend(title=expression(paste(italic("six6"), " genotype"))),
                                      shape=guide_legend(title=expression(paste(italic("six6"), " genotype"))))
         + theme(axis.title.x = element_blank()))/
  (fig_additive_and_dominance_effect_year_six6 + theme(axis.title.x = element_blank()))/
  fig_evolvability_six6 +
  plot_annotation(tag_levels = 'A')

fig3

ggsave(fig3, filename = "figs/Figure_3.pdf", width = 18, height = 18, units = "cm", device = cairo_pdf(), scale = 1)

